@@ -19,15 +19,21 @@
 #
 #   ---------------------------------------------------------------------- copyright and license ---
 
+#pod =for :this This is C<Version::Dotted> module/class documentation. Read it first, but use one of its
+#pod subclasses.
+#pod
+#pod =for :those General topics like getting source, building, installing, bug reporting and some others
+#pod are covered in the F<README>.
+#pod
 #pod =for test_synopsis my ( $v, $i, $p );
 #pod
 #pod =head1 SYNOPSIS
 #pod
-#pod     use Version::Dotted;            # import nothing
-#pod     use Version::Dotted qw{ qv };   # import qv
+#pod     use Version::Dotted;        # import nothing
+#pod     use Version::Dotted 'qv';   # import qv
 #pod
 #pod     # Construct:
-#pod     $v = Version::Dotted->new( v1.2.3 );    # the same as qv( v1.2.3 )
+#pod     $v = Version::Dotted->new( v1.2.3 );    # same as qv( v1.2.3 )
 #pod     $v = qv( v1.2.3 );      # v1.2.3
 #pod     $v = qv( '1.2.0' );     # v1.2 (trailing zero parts ignored)
 #pod     $v = qv( 'v1' );        # v1
@@ -49,13 +55,47 @@
 #pod
 #pod =head1 DESCRIPTION
 #pod
-#pod C<Version::Dotted> is a subclass of C<version>.
+#pod C<version> is an official Perl module for comparing versions. For example, (starting from Perl
+#pod 5.12.0) C<package> with a specified version:
 #pod
-#pod The class narrows C<version> — C<Version::Dotted> creates only I<dotted> (aka dotted-decimal)
-#pod version objects, support for creating decimal versions is not provided. Support for "alpha"
-#pod versions is dropped too (subclasses provides support for "trial" versions instead).
+#pod     package Assa v1.2.3;
 #pod
-#pod The class extends C<version> — C<Version::Dotted> objects are I<modifiable>.
+#pod automatically assigns C<$VERSION> variable to a version object (i. e. an object of C<version>
+#pod class).
+#pod
+#pod C<Version::Dotted> is I<not> a replacement or alternative for C<version>. Modules should continue
+#pod to use C<version> implicitly (as shown in the example above) or explicitly:
+#pod
+#pod     package Assa;
+#pod     use version 0.77; our $VERSION = version->declare( 'v1.2.3' );
+#pod
+#pod C<Version::Dotted> (or better its more specialized descendants: C<Version::Dotted::Semantic> and
+#pod C<Version::Dotted::Odd>) is intended for cases where you need to I<modify> version object. For
+#pod example, in C<Dist::Zilla> C<AfterRelease> plugin:
+#pod
+#pod     sub after_release {
+#pod         my ( $self ) = @_;
+#pod         my $v = qv( $self->zilla->version );
+#pod         $v->bump( 'trial' );    # Version of the next release.
+#pod         ...
+#pod     };
+#pod
+#pod or in C<ReleaseStatusProvider> plugin:
+#pod
+#pod     sub provide_release_status {
+#pod         my ( $self ) = @_;
+#pod         my $v = qv( $self->zilla->version );
+#pod         return $v->is_trial ? "testing" : "stable";
+#pod     };
+#pod
+#pod C<Version::Dotted> is very similar to C<Perl::Version>, but tries to avoid mess and confusing
+#pod created by supporting both decimal versions (C<1.003005>) and dotted versions (C<v1.3.5>).
+#pod C<Version::Dotted> does not support decimal versions intentionally to be simpler, cleaner and less
+#pod confusing.
+#pod
+#pod For the same purpose C<Version::Dotted> does I<not> use underscore (C<_>) to denote trial versions:
+#pod trial version C<v0.10.1_01> interpretation depends on C<version> version, it could be either
+#pod C<v0.10.1.1> or C<v0.10.101>.
 #pod
 #pod =head2 Dotted Version
 #pod
@@ -65,10 +105,21 @@
 #pod
 #pod See also L<version::Internals/"Dotted-Decimal Versions">.
 #pod
+#pod =head2 Parent(s)
+#pod
+#pod C<Version::Dotted> is heavily influenced by C<Perl::Version>, but C<Version::Dotted> is I<not> a
+#pod subclass of C<Perl::Version>, C<Version::Dotted> I<is> a subclass of C<version>.
+#pod
+#pod The class narrows C<version> — C<Version::Dotted> creates only I<dotted> (aka dotted-decimal)
+#pod version objects, support for creating decimal versions is not provided. Support for "alpha"
+#pod versions is dropped too (subclasses provide support for "trial" versions instead).
+#pod
+#pod The class extends C<version> — C<Version::Dotted> objects are I<modifiable>.
+#pod
 #pod =head2 Warnings
 #pod
-#pod Methods report error conditions by C<warnings::warnif>. It gives the caller flexibility: warning
-#pod may be either suppressed
+#pod The class reports error by C<warnings::warnif>. It gives the caller flexibility: warning may be
+#pod either suppressed
 #pod
 #pod     no warnings 'Version::Dotted';
 #pod
@@ -108,8 +159,9 @@
 #pod =back
 #pod
 #pod I think using word "alpha" by C<version> module is a confusing, because C<version> does not provide
-#pod any support for "beta" and "rc" ("release candidate"). Thus, "alpha" term is dropped in favor of
-#pod more generic term "trial": trial could be either "alpha", "beta", or "rc".
+#pod any support for "beta" and "release candidate". Thus, "alpha" term is dropped in favor of more
+#pod generic term "trial": trial could be any of "alpha", "beta", "release candidate", "unstable", or
+#pod "testing".
 #pod
 #pod However, C<Version::Dotted> does not define C<is_trial> method but leaves this for subclasses.
 #pod
@@ -123,7 +175,7 @@ use warnings::register;
 use version 0.77 qw{};
 
 # ABSTRACT: TODO
-our $VERSION = 'v0.0.0_04'; # TRIAL VERSION
+our $VERSION = 'v0.0.0_05'; # TRIAL VERSION
 
 use parent 'version';
 use overload (
@@ -145,7 +197,7 @@ sub _warn {
 
 #pod =Method C<new>
 #pod
-#pod Constructs new version object.
+#pod Constructs a new version object.
 #pod
 #pod     $version = Version::Dotted->new( $arg );
 #pod
@@ -187,6 +239,7 @@ sub _warn {
 sub new {
     my ( $class, $arg ) = @_;
     my $v;
+    use DDP; p $arg;
     defined $arg or $class->_warn( "Use of undefined value to construct version" );
     if ( ref( $arg ) and $arg->isa( 'version' ) ) {
         $v = $class->declare( 0 );                      # Create a new version object.
@@ -234,6 +287,12 @@ sub part {
 #pod
 #pod The method returns reference to version object.
 #pod
+#pod     $v = qv( v1.2.3 );  # v1.2.3
+#pod     $v->bump( 3 );      # v1.2.3.1
+#pod     $v->bump( 2 );      # v1.2.4
+#pod     $v->bump( 1 );      # v1.3
+#pod     $v->bump( 0 );      # v2
+#pod
 #pod =cut
 
 sub bump {
@@ -395,17 +454,21 @@ sub numify {
 #pod The module exports nothing by default. The module installs C<qv> function (I<not> a method) into
 #pod caller namespace by explicit request:
 #pod
-#pod     use Version::Dotted qw{ qv };
+#pod     use Version::Dotted 'qv';
+#pod
+#pod If caller module already has C<qv> function, warning is issued and function is redefined.
+#pod
+#pod Note: C<version> exports C<qv> by default, if caller package does not have C<qv> function yet.
 #pod
 #pod The module (unlike to C<version>) does not play any tricks with importer's C<VERSION> and/or
 #pod C<UNIVERSAL::VERSION>.
 #pod
 #pod =func qv
 #pod
-#pod Shortcut for C<Version::Dotted->new>.
+#pod Shortcut for C<Version::Dotted-E<gt>new>.
 #pod
 #pod     $v = Version::Dotted->new( $arg );
-#pod     $v = qv( $arv );
+#pod     $v = qv( $arv );    # ditto
 #pod
 #pod Note: There is I<no> function C<Version::Dotted::qv>, C<qv> function is installed into importer
 #pod package by explicit request, see L</"EXPORT">.
@@ -413,15 +476,18 @@ sub numify {
 #pod =cut
 
 #   We have to redefine parents' import. Otherwise we will export `qv` into importer namespace by
-#   default. Explicit import of `qv` could be a good idea, though.
+#   default. Explicit import of `qv` is a good idea, though.
 
 sub import {
     my ( $class, @list ) = @_;
     my $pkg = caller();
     my %args = map( { $_ => 1 } @list );
     if ( delete( $args{ qv } ) ) {
+        my $qv = $pkg . '::qv';
         no strict 'refs';               ## no critic ( ProhibitNoStrict )
-        *{ $pkg . '::qv' } = sub {
+        no warnings 'redefine';         ## no critic ( ProhibitNoWarnings )
+        $class->_warn( "Subroutine $qv redefined" ) if defined &$qv;
+        *$qv = sub {
             return $class->new( @_ );
         };
     };
@@ -446,16 +512,20 @@ sub import {
 #pod
 #pod = L<Perl::Version>
 #pod
-#pod An alternative to C<version>. Works with both decimal and dotted versions, provides modification
+#pod An alternative to C<version>. It works with both decimal and dotted versions, provides modification
 #pod operations. Release status depends on presence of underscore character in version.
 #pod
+#pod = L<SemVer>
+#pod
+#pod TODO
+#pod
 #pod = L<Version::Dotted::Semantic>
 #pod
 #pod Subclass implementing Perlish approach to Semantic Versioning.
 #pod
 #pod = L<Version::Dotted::Odd>
 #pod
-#pod Subclass implementing odd-even versioning scheme.
+#pod Subclass implementing odd/even versioning scheme.
 #pod
 #pod =end :list
 #pod
@@ -484,7 +554,8 @@ sub import {
 #pod
 #pod =head1 WHAT?
 #pod
-#pod TODO
+#pod C<Version::Dotted> and its subclasses complement standard C<version> class with version
+#pod modification operations, which can be useful in distribution release tools.
 #pod
 #pod =cut
 
@@ -524,8 +595,7 @@ sub import {
 #pod
 #pod     version->parse( 'v0.10.1_01' ) > 'v0.10.2'  # is true
 #pod
-#pod Oops. That's was quite surprising, because I remembered some time ago this expression had opposite
-#pod result:
+#pod Oops. That's was quite surprising, because some time ago this expression had opposite result:
 #pod
 #pod     version->parse( 'v0.10.1_01' ) < 'v0.10.2'  # was true
 #pod
@@ -559,22 +629,29 @@ Version::Dotted - TODO
 
 =head1 VERSION
 
-Version v0.0.0_04, released on 2016-12-27 20:03 UTC.
+Version v0.0.0_05, released on 2016-12-28 19:36 UTC.
 This is a B<trial release>.
 
 =head1 WHAT?
 
-TODO
+C<Version::Dotted> and its subclasses complement standard C<version> class with version
+modification operations, which can be useful in distribution release tools.
+
+This is C<Version::Dotted> module/class documentation. Read it first, but use one of its
+subclasses.
+
+General topics like getting source, building, installing, bug reporting and some others
+are covered in the F<README>.
 
 =for test_synopsis my ( $v, $i, $p );
 
 =head1 SYNOPSIS
 
-    use Version::Dotted;            # import nothing
-    use Version::Dotted qw{ qv };   # import qv
+    use Version::Dotted;        # import nothing
+    use Version::Dotted 'qv';   # import qv
 
     # Construct:
-    $v = Version::Dotted->new( v1.2.3 );    # the same as qv( v1.2.3 )
+    $v = Version::Dotted->new( v1.2.3 );    # same as qv( v1.2.3 )
     $v = qv( v1.2.3 );      # v1.2.3
     $v = qv( '1.2.0' );     # v1.2 (trailing zero parts ignored)
     $v = qv( 'v1' );        # v1
@@ -596,13 +673,47 @@ TODO
 
 =head1 DESCRIPTION
 
-C<Version::Dotted> is a subclass of C<version>.
+C<version> is an official Perl module for comparing versions. For example, (starting from Perl
+5.12.0) C<package> with a specified version:
 
-The class narrows C<version> — C<Version::Dotted> creates only I<dotted> (aka dotted-decimal)
-version objects, support for creating decimal versions is not provided. Support for "alpha"
-versions is dropped too (subclasses provides support for "trial" versions instead).
+    package Assa v1.2.3;
 
-The class extends C<version> — C<Version::Dotted> objects are I<modifiable>.
+automatically assigns C<$VERSION> variable to a version object (i. e. an object of C<version>
+class).
+
+C<Version::Dotted> is I<not> a replacement or alternative for C<version>. Modules should continue
+to use C<version> implicitly (as shown in the example above) or explicitly:
+
+    package Assa;
+    use version 0.77; our $VERSION = version->declare( 'v1.2.3' );
+
+C<Version::Dotted> (or better its more specialized descendants: C<Version::Dotted::Semantic> and
+C<Version::Dotted::Odd>) is intended for cases where you need to I<modify> version object. For
+example, in C<Dist::Zilla> C<AfterRelease> plugin:
+
+    sub after_release {
+        my ( $self ) = @_;
+        my $v = qv( $self->zilla->version );
+        $v->bump( 'trial' );    # Version of the next release.
+        ...
+    };
+
+or in C<ReleaseStatusProvider> plugin:
+
+    sub provide_release_status {
+        my ( $self ) = @_;
+        my $v = qv( $self->zilla->version );
+        return $v->is_trial ? "testing" : "stable";
+    };
+
+C<Version::Dotted> is very similar to C<Perl::Version>, but tries to avoid mess and confusing
+created by supporting both decimal versions (C<1.003005>) and dotted versions (C<v1.3.5>).
+C<Version::Dotted> does not support decimal versions intentionally to be simpler, cleaner and less
+confusing.
+
+For the same purpose C<Version::Dotted> does I<not> use underscore (C<_>) to denote trial versions:
+trial version C<v0.10.1_01> interpretation depends on C<version> version, it could be either
+C<v0.10.1.1> or C<v0.10.101>.
 
 =head2 Dotted Version
 
@@ -612,10 +723,21 @@ can be bigger than 999.
 
 See also L<version::Internals/"Dotted-Decimal Versions">.
 
+=head2 Parent(s)
+
+C<Version::Dotted> is heavily influenced by C<Perl::Version>, but C<Version::Dotted> is I<not> a
+subclass of C<Perl::Version>, C<Version::Dotted> I<is> a subclass of C<version>.
+
+The class narrows C<version> — C<Version::Dotted> creates only I<dotted> (aka dotted-decimal)
+version objects, support for creating decimal versions is not provided. Support for "alpha"
+versions is dropped too (subclasses provide support for "trial" versions instead).
+
+The class extends C<version> — C<Version::Dotted> objects are I<modifiable>.
+
 =head2 Warnings
 
-Methods report error conditions by C<warnings::warnif>. It gives the caller flexibility: warning
-may be either suppressed
+The class reports error by C<warnings::warnif>. It gives the caller flexibility: warning may be
+either suppressed
 
     no warnings 'Version::Dotted';
 
@@ -655,8 +777,9 @@ C<dzil> tool has C<--trial> command line option to build a "release that PAUSE w
 =back
 
 I think using word "alpha" by C<version> module is a confusing, because C<version> does not provide
-any support for "beta" and "rc" ("release candidate"). Thus, "alpha" term is dropped in favor of
-more generic term "trial": trial could be either "alpha", "beta", or "rc".
+any support for "beta" and "release candidate". Thus, "alpha" term is dropped in favor of more
+generic term "trial": trial could be any of "alpha", "beta", "release candidate", "unstable", or
+"testing".
 
 However, C<Version::Dotted> does not define C<is_trial> method but leaves this for subclasses.
 
@@ -665,7 +788,11 @@ However, C<Version::Dotted> does not define C<is_trial> method but leaves this f
 The module exports nothing by default. The module installs C<qv> function (I<not> a method) into
 caller namespace by explicit request:
 
-    use Version::Dotted qw{ qv };
+    use Version::Dotted 'qv';
+
+If caller module already has C<qv> function, warning is issued and function is redefined.
+
+Note: C<version> exports C<qv> by default, if caller package does not have C<qv> function yet.
 
 The module (unlike to C<version>) does not play any tricks with importer's C<VERSION> and/or
 C<UNIVERSAL::VERSION>.
@@ -674,7 +801,7 @@ C<UNIVERSAL::VERSION>.
 
 =head2 C<new>
 
-Constructs new version object.
+Constructs a new version object.
 
     $version = Version::Dotted->new( $arg );
 
@@ -726,6 +853,12 @@ Negative part index causes warning but works.
 
 The method returns reference to version object.
 
+    $v = qv( v1.2.3 );  # v1.2.3
+    $v->bump( 3 );      # v1.2.3.1
+    $v->bump( 2 );      # v1.2.4
+    $v->bump( 1 );      # v1.3
+    $v->bump( 0 );      # v2
+
 =head2 C<is_alpha>
 
 The method prints a warning and always returns C<undef>.
@@ -749,10 +882,10 @@ stringification is always a dotted version string with leading C<'v'>, e. g.:
 
 =head2 qv
 
-Shortcut for C<Version::Dotted->new>.
+Shortcut for C<Version::Dotted-E<gt>new>.
 
     $v = Version::Dotted->new( $arg );
-    $v = qv( $arv );
+    $v = qv( $arv );    # ditto
 
 Note: There is I<no> function C<Version::Dotted::qv>, C<qv> function is installed into importer
 package by explicit request, see L</"EXPORT">.
@@ -827,8 +960,7 @@ Everything was ok. However, I accidentally found that
 
     version->parse( 'v0.10.1_01' ) > 'v0.10.2'  # is true
 
-Oops. That's was quite surprising, because I remembered some time ago this expression had opposite
-result:
+Oops. That's was quite surprising, because some time ago this expression had opposite result:
 
     version->parse( 'v0.10.1_01' ) < 'v0.10.2'  # was true
 
@@ -854,16 +986,20 @@ provide any modifiers. Release status depends on presence of underscore characte
 
 =item L<Perl::Version>
 
-An alternative to C<version>. Works with both decimal and dotted versions, provides modification
+An alternative to C<version>. It works with both decimal and dotted versions, provides modification
 operations. Release status depends on presence of underscore character in version.
 
+=item L<SemVer>
+
+TODO
+
 =item L<Version::Dotted::Semantic>
 
 Subclass implementing Perlish approach to Semantic Versioning.
 
 =item L<Version::Dotted::Odd>
 
-Subclass implementing odd-even versioning scheme.
+Subclass implementing odd/even versioning scheme.
 
 =back
 
