@@ -19,12 +19,18 @@
 #
 #   ---------------------------------------------------------------------- copyright and license ---
 
+#pod =for :this This is C<Version::Dotted::Odd> module/class documentation. However, read
+#pod C<Version::Dotted> module/class documentation first, since it contains many relevant details.
+#pod
+#pod =for :those General topics like getting source, building, installing, bug reporting and some
+#pod others are covered in the F<README>.
+#pod
 #pod =for test_synopsis my $v;
 #pod
 #pod =head1 SYNOPSIS
 #pod
-#pod     use Version::Dotted::Odd;           # import nothing
-#pod     use Version::Dotted::Odd qw{ qv };  # import qv
+#pod     use Version::Dotted::Odd;       # import nothing
+#pod     use Version::Dotted::Odd 'qv';  # import qv
 #pod
 #pod     # Construct:
 #pod     $v = Version::Dotted::Odd->new( v1.0 );     # v1.0.0 (at least 3 parts)
@@ -59,7 +65,7 @@
 #pod
 #pod     $v = qv( v1.0 );        # $v == v1.0.0
 #pod     $v->is_trial;           # false
-#pod     $v += v0.1;             # $v == v1.1.0
+#pod     $v->bump( 1 );          # $v == v1.1.0
 #pod     $v->is_trial;           # true
 #pod
 #pod =back
@@ -73,8 +79,8 @@ package Version::Dotted::Odd;
 use strict;
 use warnings;
 
-# ABSTRACT: TODO
-our $VERSION = 'v0.0.0_04'; # TRIAL VERSION
+# ABSTRACT: Use odd/even versioning scheme in your Perl modules
+our $VERSION = 'v0.0.0_05'; # TRIAL VERSION
 
 use parent 'Version::Dotted';
 
@@ -130,7 +136,8 @@ sub is_trial {
 #pod
 #pod =head1 WHAT?
 #pod
-#pod TODO
+#pod C<Version::Dotted> and its subclasses complement standard C<version> class with version
+#pod modification operations, which can be useful in distribution release tools.
 #pod
 #pod =cut
 
@@ -147,23 +154,30 @@ __END__
 
 =head1 NAME
 
-Version::Dotted::Odd - TODO
+Version::Dotted::Odd - Use odd/even versioning scheme in your Perl modules
 
 =head1 VERSION
 
-Version v0.0.0_04, released on 2016-12-27 20:03 UTC.
+Version v0.0.0_05, released on 2016-12-28 19:36 UTC.
 This is a B<trial release>.
 
 =head1 WHAT?
 
-TODO
+C<Version::Dotted> and its subclasses complement standard C<version> class with version
+modification operations, which can be useful in distribution release tools.
+
+This is C<Version::Dotted::Odd> module/class documentation. However, read
+C<Version::Dotted> module/class documentation first, since it contains many relevant details.
+
+General topics like getting source, building, installing, bug reporting and some
+others are covered in the F<README>.
 
 =for test_synopsis my $v;
 
 =head1 SYNOPSIS
 
-    use Version::Dotted::Odd;           # import nothing
-    use Version::Dotted::Odd qw{ qv };  # import qv
+    use Version::Dotted::Odd;       # import nothing
+    use Version::Dotted::Odd 'qv';  # import qv
 
     # Construct:
     $v = Version::Dotted::Odd->new( v1.0 );     # v1.0.0 (at least 3 parts)
@@ -198,7 +212,7 @@ The second part defines the release status: odd numbers denotes a trial release.
 
     $v = qv( v1.0 );        # $v == v1.0.0
     $v->is_trial;           # false
-    $v += v0.1;             # $v == v1.1.0
+    $v->bump( 1 );          # $v == v1.1.0
     $v->is_trial;           # true
 
 =back
